# Repository path:    $HeadURL: https://90.145.156.222/DMS-Houtribdijk/code/python-ftp-svn/source/misc/Utils.py $
# Last committed:     $Revision: 347639 $; $Author: svcdms $; $Date: 2019-10-02 16:39:05 +0200 (wo, 02 okt 2019) $
#
from json import load, JSONDecodeError
from .REMatcher import REMatcher

class Utils:

    # read the json with the site specification and return it in a dictionary
    @staticmethod
    def read_json(f):
        with open(f) as json_file:
            jsondoc = load(json_file)
        return jsondoc

    # read the json and check for the presence of the expected keys
    @staticmethod
    def read_settings(file, expected_keys):
        try:
            settings = Utils.read_json(file)
        except FileNotFoundError:
            print("ERROR: The file {} could not be found.".format(file))
            exit(1)
        except JSONDecodeError:
            print("ERROR: The file {} is not a valid json file.".format(file))
            exit(1)
        else:
            # test presence expected keys
            for k in expected_keys:
                try:
                    dummy = settings[k]
                except KeyError:
                    print(
                        "ERROR: Expected key {} is not found in file {}.".format(
                            k, file
                        )
                    )
                    exit(1)
            return settings

    @staticmethod
    def get_location_from_filename(fn, pat):
        m = REMatcher(fn)
        if m.search(pat):
            try:
                if m.group(2) == "":
                    return m.group(1)
                else:
                    return m.group(1) + "_" + m.group(2)
            except IndexError:
                return m.group(1)
        else:
            return ""

    @staticmethod
    def read_folder_settings():
        settings_file = "./connections/folders_settings.json"
        expected_keys = [
            "log_folder",
            "primary_root",
            "secondary_ftp",
            "secondary_root",
            "status_folder",
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_ftp_settings():
        settings_file = "./connections/ftp_settings.json"
        expected_keys = ["url", "usr", "pw"]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_db_settings():
        settings_file = "./connections/db_settings.json"
        expected_keys = ["host", "dbname", "user", "password"]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_process_settings(settings_file):
        expected_keys = [
            "pi_service",
            "process_name",
            "reader_object",
            "import_folder",
            "import_failed",
            "filter",
            "moduleInstance",
            "location_pattern",
            "log_folder",
            "logger",
            "logfile",
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_location_settings():
        settings_file = "./connections/location_settings.json"
        expected_keys = ["status_folder", "metadata_file", "logboek_file", "drukoffset_file"]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_monitor_ftp_settings(settings_file):
        expected_keys = [
            "secondary_root",
            "hkvservices",
            "startdate_delta",
            "database",
            "ftp_overview",
            "log_folder",
            "logger",
            "logfile"
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_thredds_settings(settings_file):
        expected_keys = [
            "thredds_server",
            "hkvservices",
            "startdate_delta",
            "database",
            "thredds_overview",
            "log_folder",
            "logger",
            "logfile"
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_excel_settings(settings_file):
        expected_keys = [
            "excel_root",
            "hkvservices",
            "database",
            "log_folder",
            "logger",
            "logfile"
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_bin2ascii_settings(settings_file):
        expected_keys = [
            "executable",
            "import_folder",
            "output_folder",
            "import_backup",
            "log_folder",
            "logger",
            "logfile",
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_monitor_status_locs_sensors_settings(settings_file):
        expected_keys = [
            "pi_url",
            "filter_id",
            "parameter_ids",
            "location_ids",
            "status_overview",
            "output_location",
            "log_folder",
            "logger",
            "logfile",
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_monitor_data_where_status_settings(settings_file):
        expected_keys = [
            "folder_importbackup",
            "folder_ftpstatus_status",
            "folder_ftpstatus_data",
            #"location_pattern",
            "file_monitor_out",
            "log_folder",
            "logger",
            "logfile",
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod   
    def read_monitor_checks_settings(settings_file):
        expected_keys = [
            "thredds_url",
            "hkvservices",
            "file_monitor_out",
            "checks_abs",
            "checks_dif",
            "database",
            "log_folder",
            "logger",
            "logfile"            
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod   
    def read_monitor_sensors_settings(settings_file):
        expected_keys = [
            "hkvservices",
            "database",
            "log_folder",
            "logger",
            "logfile"            
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_monitor_status_import_backup_settings(settings_file):
        expected_keys = [
            "folder_importbackup",
            "folder_ftpstatus_status",
            "folder_ftpstatus_data",
            "file_monitor_out",
            "log_folder",
            "logger",
            "logfile",
        ]
        return Utils.read_settings(settings_file, expected_keys)

    @staticmethod
    def read_nc_export_settings(settings_file):
        expected_keys = [
            "pi_restservice",
            "metadatafile_location",
            "ncdir",
        ]
        return Utils.read_settings(settings_file, expected_keys)


    @staticmethod
    def get_timestamp_from_filename(fn, pat, thredds=False):
        m = REMatcher(fn)
        if m.search(pat):
            if thredds:
                return m.group(1)[:14]
            else:
                return '20' + m.group(1)[:10]
        else:
            return ''


